@@ -1,62 +1,11 @@
 //! Types and traits for easily getting a message's arguments, or appening a message with arguments.
 //!
-//! Also see the arguments guide (in the examples directory).
+//! Also see the argument's guide (in the examples directory) for details about which Rust
+//! types correspond to which D-Bus types.
 //!
-//! A message has `read1`, `read2` etc, and `append1`, `append2` etc, which is your
+//! A message has `read1`, `read2` etc, and `append1`, `append2` etc, which is one
 //! starting point into this module's types.
-//!
-//! **Append a**:
-//!
-//! `bool, u8, u16, u32, u64, i16, i32, i64, f64` - the corresponding D-Bus basic type
-//!
-//! `&str` - a D-Bus string. D-Bus strings do not allow null characters, so
-//! if the string contains null characters, it will be cropped
-//! to only include the data before the null character. (Tip: This allows for skipping an
-//! allocation by writing a string literal which ends with a null character.)
-//!
-//! `&[T] where T: Append` - a D-Bus array. Note: can use an efficient fast-path in case of
-//! T being an FixedArray type.
-//!
-//! `Array<T, I> where T: Append, I: Iterator<Item=T>` - a D-Bus array, maximum flexibility.
-//!
-//! `Variant<T> where T: Append` - a D-Bus variant.
-//!
-//! `(T1, T2) where T1: Append, T2: Append` - tuples are D-Bus structs. Implemented up to 12.
-//!
-//! `Dict<K, V, I> where K: Append + DictKey, V: Append, I: Iterator<Item=(&K, &V)>` - A D-Bus dict (array of dict entries).
-//!
-//! `Path` - a D-Bus object path.
-//!
-//! `Signature` - a D-Bus signature.
-//!
-//! `OwnedFd` - shares the file descriptor with the remote side.
-//!
-//! **Get / read a**:
-//!
-//! `bool, u8, u16, u32, u64, i16, i32, i64, f64` - the corresponding D-Bus basic type
-//!
-//! `&str`, `&CStr` - a D-Bus string. D-Bus strings are always UTF-8 and do not contain null characters.
-//!
-//! `&[T] where T: FixedArray` - a D-Bus array of integers or f64.
-//!
-//! `Array<T, Iter> where T: Get` - a D-Bus array, maximum flexibility. Implements Iterator so you can easily
-//! collect it into, e g, a `Vec`.
-//!
-//! `Variant<T> where T: Get` - a D-Bus variant. Use this type of Variant if you know the inner type.
-//!
-//! `Variant<Iter>` - a D-Bus variant. This type of Variant allows you to examine the inner type.
-//!
-//! `(T1, T2) where T1: Get, T2: Get` - tuples are D-Bus structs. Implemented up to 12.
-//!
-//! `Dict<K, V, Iter> where K: Get + DictKey, V: Get` - A D-Bus dict (array of dict entries). Implements Iterator so you can easily
-//! collect it into, e g, a `HashMap`.
-//!
-//! `Path` - a D-Bus object path.
-//!
-//! `Signature` - a D-Bus signature.
-//!
-//! `OwnedFd` - a file descriptor sent from the remote side.
-//!
+
 
 mod msgarg;
 mod basic_impl;
@@ -65,7 +14,8 @@ mod array_impl;
 
 pub mod messageitem;
 
-pub use self::msgarg::{Arg, FixedArray, Get, DictKey, Append, RefArg, AppendAll, ReadAll, ArgAll, cast, cast_mut, prop_cast};
+pub use self::msgarg::{Arg, FixedArray, Get, DictKey, Append, RefArg, AppendAll, ReadAll, ArgAll,
+    cast, cast_mut, prop_cast, PropMap};
 pub use self::array_impl::{Array, Dict};
 pub use self::variantstruct_impl::Variant;
 
@@ -73,6 +23,7 @@ use std::{fmt, mem, ptr, error};
 use crate::{ffi, Message, Signature, Path};
 use std::ffi::{CStr, CString};
 use std::os::raw::{c_void, c_int};
+#[cfg(unix)]
 use std::os::unix::io::{RawFd, AsRawFd, FromRawFd, IntoRawFd};
 use std::collections::VecDeque;
 
@@ -87,9 +38,11 @@ fn ffi_iter() -> ffi::DBusMessageIter {
 /// when the scope ends.
 #[derive(Debug, PartialEq, PartialOrd)]
 pub struct OwnedFd {
+    #[cfg(unix)]
     fd: RawFd
 }
 
+#[cfg(unix)]
 impl OwnedFd {
     /// Create a new OwnedFd from a RawFd.
     ///
@@ -107,6 +60,7 @@ impl OwnedFd {
     }
 }
 
+#[cfg(unix)]
 impl Drop for OwnedFd {
     fn drop(&mut self) {
         unsafe { libc::close(self.fd); }
@@ -114,25 +68,34 @@ impl Drop for OwnedFd {
 }
 
 impl Clone for OwnedFd {
+    #[cfg(unix)]
     fn clone(&self) -> OwnedFd {
         let x = unsafe { libc::dup(self.fd) };
         if x == -1 { panic!("Duplicating file descriptor failed") }
         unsafe { OwnedFd::new(x) }
     }
+
+    #[cfg(windows)]
+    fn clone(&self) -> OwnedFd {
+        OwnedFd {}
+    }
 }
 
+#[cfg(unix)]
 impl AsRawFd for OwnedFd {
     fn as_raw_fd(&self) -> RawFd {
         self.fd
     }
 }
 
+#[cfg(unix)]
 impl IntoRawFd for OwnedFd {
     fn into_raw_fd(self) -> RawFd {
         self.into_fd()
     }
 }
 
+#[cfg(unix)]
 impl FromRawFd for OwnedFd {
     unsafe fn from_raw_fd(fd: RawFd) -> Self { OwnedFd::new(fd) }
 }
@@ -239,12 +202,7 @@ impl<'a> Iter<'a> {
 
     /// Returns the current argument as a trait object.
     ///
-    /// Note: For the more complex arguments (arrays / dicts / structs, and especially
-    /// combinations thereof), their internal representations are still a bit in flux.
-    /// Instead, use as_iter() to read the values of those.
-    ///
-    /// The rest are unlikely to change - Variants are `Variant<Box<dyn RefArg>>`, strings are `String`,
-    /// paths are `Path<'static>`, signatures are `Signature<'static>`, Int32 are `i32s` and so on.
+    /// See the argument guide's reference part for information on what types hide inside the RefArg.
     pub fn get_refarg(&mut self) -> Option<Box<dyn RefArg + 'static>> {
         Some(match self.arg_type() {
             ArgType::Array => array_impl::get_array_refarg(self),
@@ -261,7 +219,7 @@ impl<'a> Iter<'a> {
             ArgType::Int64 => Box::new(self.get::<i64>().unwrap()),
             ArgType::UInt64 => Box::new(self.get::<u64>().unwrap()),
             ArgType::Double => Box::new(self.get::<f64>().unwrap()),
-            ArgType::UnixFd => Box::new(self.get::<OwnedFd>().unwrap()),
+            ArgType::UnixFd => Box::new(self.get::<std::fs::File>().unwrap()),
             ArgType::Struct => Box::new(self.recurse(ArgType::Struct).unwrap().collect::<VecDeque<_>>()),
             ArgType::ObjectPath => Box::new(self.get::<Path>().unwrap().into_static()),
             ArgType::Signature => Box::new(self.get::<Signature>().unwrap().into_static()),
@@ -403,7 +361,7 @@ pub enum ArgType {
     UInt64 = ffi::DBUS_TYPE_UINT64 as u8,
     /// f64
     Double = ffi::DBUS_TYPE_DOUBLE as u8,
-    /// OwnedFd
+    /// File
     UnixFd = ffi::DBUS_TYPE_UNIX_FD as u8,
     /// Use tuples or Vec<Box<dyn RefArg>> to read/write structs.
     Struct = ffi::DBUS_TYPE_STRUCT as u8,
@@ -421,7 +379,7 @@ const ALL_ARG_TYPES: [(ArgType, &str); 18] =
     (ArgType::DictEntry, "Dict entry"),
     (ArgType::ObjectPath, "Path"),
     (ArgType::Signature, "Signature"),
-    (ArgType::UnixFd, "OwnedFd"),
+    (ArgType::UnixFd, "File"),
     (ArgType::Boolean, "bool"),
     (ArgType::Byte, "u8"),
     (ArgType::Int16, "i16"),
